==> kdepimlibs-4.2.2_1.tbz: lib/KdepimLibs/cmake/KDEPimLibsLibraryTargetsWithPrefix-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "release".
#----------------------------------------------------------------

# Commands may need to know the format version.
SET(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDEPIMLibs__gpgmepp" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__gpgmepp APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__gpgmepp PROPERTIES
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libgpgme++.so.2.0.2"
  IMPORTED_SONAME_RELEASE "libgpgme++.so.2"
  )

# Import target "KDEPIMLibs__gpgmepp-pthread" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__gpgmepp-pthread APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__gpgmepp-pthread PROPERTIES
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libgpgme++-pthread.so.2.0.2"
  IMPORTED_SONAME_RELEASE "libgpgme++-pthread.so.2"
  )

# Import target "KDEPIMLibs__qgpgme" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__qgpgme APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__qgpgme PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDEPIMLibs__gpgmepp-pthread"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libqgpgme.so.1.0.1"
  IMPORTED_SONAME_RELEASE "libqgpgme.so.1"
  )

# Import target "KDEPIMLibs__kmime" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kmime APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kmime PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdecore"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkmime.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkmime.so.5"
  )

# Import target "KDEPIMLibs__akonadi-kabc" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__akonadi-kabc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__akonadi-kabc PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDEPIMLibs__akonadi-kde;KDE4__kdecore"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libakonadi-kabc.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libakonadi-kabc.so.5"
  )

# Import target "KDEPIMLibs__akonadi-kmime" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__akonadi-kmime APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__akonadi-kmime PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDEPIMLibs__akonadi-kde;KDEPIMLibs__kmime;KDE4__kdecore;KDE4__kio"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libakonadi-kmime.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libakonadi-kmime.so.5"
  )

# Import target "KDEPIMLibs__akonadi-kde" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__akonadi-kde APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__akonadi-kde PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__solid;KDE4__kdeui;KDE4__kio"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libakonadi-kde.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libakonadi-kde.so.5"
  )

# Import target "KDEPIMLibs__kabc_file_core" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kabc_file_core APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kabc_file_core PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio;KDEPIMLibs__kabc;KDEPIMLibs__kcal;KDEPIMLibs__kresources"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkabc_file_core.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkabc_file_core.so.5"
  )

# Import target "KDEPIMLibs__kabc" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kabc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kabc PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDEPIMLibs__kldap;KDE4__kdecore"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDEPIMLibs__kresources;KDE4__kdeui"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkabc.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkabc.so.5"
  )

# Import target "KDEPIMLibs__kblog" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kblog APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kblog PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDEPIMLibs__kxmlrpcclient;KDEPIMLibs__syndication;KDE4__kio;KDEPIMLibs__kcal"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkblog.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkblog.so.5"
  )

# Import target "KDEPIMLibs__kcal" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kcal APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kcal PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui;KDE4__kio;KDEPIMLibs__kpimutils"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDEPIMLibs__kresources;KDEPIMLibs__kabc"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkcal.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkcal.so.5"
  )

# Import target "KDEPIMLibs__kimap" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kimap APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kimap PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdecore"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkimap.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkimap.so.5"
  )

# Import target "KDEPIMLibs__kldap" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kldap APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kldap PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio;KDE4__kdecore"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkldap.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkldap.so.5"
  )

# Import target "KDEPIMLibs__kpimidentities" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kpimidentities APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kpimidentities PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDEPIMLibs__kpimutils;KDE4__kio"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkpimidentities.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkpimidentities.so.5"
  )

# Import target "KDEPIMLibs__kpimutils" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kpimutils APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kpimutils PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui;KDE4__kutils;KDEPIMLibs__kmime"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkpimutils.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkpimutils.so.5"
  )

# Import target "KDEPIMLibs__kresources" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kresources APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kresources PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkresources.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkresources.so.5"
  )

# Import target "KDEPIMLibs__ktnef" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__ktnef APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__ktnef PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio;KDEPIMLibs__kabc;KDEPIMLibs__kcal"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libktnef.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libktnef.so.5"
  )

# Import target "KDEPIMLibs__kxmlrpcclient" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kxmlrpcclient APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kxmlrpcclient PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkxmlrpcclient.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkxmlrpcclient.so.5"
  )

# Import target "KDEPIMLibs__mailtransport" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__mailtransport APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__mailtransport PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libmailtransport.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libmailtransport.so.5"
  )

# Import target "KDEPIMLibs__syndication" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__syndication APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__syndication PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libsyndication.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libsyndication.so.5"
  )

# Commands beyond this point should not need to know the version.
SET(CMAKE_IMPORT_FILE_VERSION)

==> kdepimlibs-4.3.1.tbz: lib/KdepimLibs/cmake/KDEPimLibsLibraryTargetsWithPrefix-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "release".
#----------------------------------------------------------------

# Commands may need to know the format version.
SET(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDEPIMLibs__gpgmepp" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__gpgmepp APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__gpgmepp PROPERTIES
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libgpgme++.so.2.2.1"
  IMPORTED_SONAME_RELEASE "libgpgme++.so.2"
  )

# Import target "KDEPIMLibs__gpgmepp-pthread" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__gpgmepp-pthread APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__gpgmepp-pthread PROPERTIES
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libgpgme++-pthread.so.2.2.1"
  IMPORTED_SONAME_RELEASE "libgpgme++-pthread.so.2"
  )

# Import target "KDEPIMLibs__qgpgme" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__qgpgme APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__qgpgme PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDEPIMLibs__gpgmepp-pthread"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libqgpgme.so.1.0.1"
  IMPORTED_SONAME_RELEASE "libqgpgme.so.1"
  )

# Import target "KDEPIMLibs__akonadi-kabc" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__akonadi-kabc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__akonadi-kabc PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDEPIMLibs__akonadi-kde;KDE4__kdecore"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libakonadi-kabc.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libakonadi-kabc.so.5"
  )

# Import target "KDEPIMLibs__akonadi-kmime" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__akonadi-kmime APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__akonadi-kmime PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDEPIMLibs__akonadi-kde;KDEPIMLibs__kmime;KDE4__kdecore;KDE4__kio"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libakonadi-kmime.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libakonadi-kmime.so.5"
  )

# Import target "KDEPIMLibs__akonadi-kde" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__akonadi-kde APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__akonadi-kde PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__solid;KDE4__kdeui;KDE4__kio"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libakonadi-kde.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libakonadi-kde.so.5"
  )

# Import target "KDEPIMLibs__kabc_file_core" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kabc_file_core APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kabc_file_core PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio;KDEPIMLibs__kabc;KDEPIMLibs__kcal;KDEPIMLibs__kresources"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkabc_file_core.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkabc_file_core.so.5"
  )

# Import target "KDEPIMLibs__kabc" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kabc APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kabc PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDEPIMLibs__kldap;KDE4__kdecore"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDEPIMLibs__kresources;KDE4__kdeui"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkabc.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkabc.so.5"
  )

# Import target "KDEPIMLibs__kblog" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kblog APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kblog PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDEPIMLibs__kxmlrpcclient;KDEPIMLibs__syndication;KDE4__kio;KDEPIMLibs__kcal"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkblog.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkblog.so.5"
  )

# Import target "KDEPIMLibs__kcal" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kcal APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kcal PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui;KDE4__kio;KDEPIMLibs__kpimutils"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDEPIMLibs__kresources;KDEPIMLibs__kabc"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkcal.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkcal.so.5"
  )

# Import target "KDEPIMLibs__kholidays" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kholidays APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kholidays PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkholidays.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkholidays.so.5"
  )

# Import target "KDEPIMLibs__kimap" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kimap APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kimap PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdecore;KDEPIMLibs__kmime"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkimap.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkimap.so.5"
  )

# Import target "KDEPIMLibs__kldap" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kldap APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kldap PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio;KDE4__kdecore"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkldap.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkldap.so.5"
  )

# Import target "KDEPIMLibs__kmime" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kmime APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kmime PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdecore"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkmime.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkmime.so.5"
  )

# Import target "KDEPIMLibs__kpimidentities" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kpimidentities APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kpimidentities PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDEPIMLibs__kpimutils;KDE4__kio;KDEPIMLibs__kpimtextedit"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkpimidentities.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkpimidentities.so.5"
  )

# Import target "KDEPIMLibs__kpimutils" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kpimutils APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kpimutils PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui;KDE4__kutils;KDEPIMLibs__kmime"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkpimutils.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkpimutils.so.5"
  )

# Import target "KDEPIMLibs__kresources" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kresources APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kresources PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkresources.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkresources.so.5"
  )

# Import target "KDEPIMLibs__ktnef" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__ktnef APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__ktnef PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio;KDEPIMLibs__kabc;KDEPIMLibs__kcal"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libktnef.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libktnef.so.5"
  )

# Import target "KDEPIMLibs__kxmlrpcclient" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kxmlrpcclient APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kxmlrpcclient PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkxmlrpcclient.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkxmlrpcclient.so.5"
  )

# Import target "KDEPIMLibs__mailtransport" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__mailtransport APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__mailtransport PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libmailtransport.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libmailtransport.so.5"
  )

# Import target "KDEPIMLibs__microblog" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__microblog APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__microblog PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdecore;KDEPIMLibs__kpimutils"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libmicroblog.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libmicroblog.so.5"
  )

# Import target "KDEPIMLibs__kpimtextedit" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__kpimtextedit APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__kpimtextedit PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui;KDE4__kio;KDEPIMLibs__kmime"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkpimtextedit.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libkpimtextedit.so.5"
  )

# Import target "KDEPIMLibs__syndication" for configuration "release"
SET_PROPERTY(TARGET KDEPIMLibs__syndication APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDEPIMLibs__syndication PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libsyndication.so.5.0.1"
  IMPORTED_SONAME_RELEASE "libsyndication.so.5"
  )

# Commands beyond this point should not need to know the version.
SET(CMAKE_IMPORT_FILE_VERSION)
